Struct MetadataListenerLocalBuilder

pub struct MetadataListenerLocalBuilder<'meta> { /* private fields */ }
A builder for registering metadata event callbacks.

Use Metadata::add_listener_local to create this and register callbacks that will be called when events of interest occur. After adding callbacks, use register to get back a MetadataListener.

Examples

let metadata_listener = metadata.add_listener_local()
    .property(|subject, key, type_, value| {
        println!("Metadata property update: subject {subject}, key {key:?}, type {type_:?}, value {value:?}");
        0
    })
    .register();

Implementations

Source

impl<'meta> MetadataListenerLocalBuilder<'meta>

pub fn property<F>(self, property: F) -> Self
where F: Fn(u32, Option<&str>, Option<&str>, Option<&str>) -> i32 + 'static,

Set the metadata property event callback of the listener.

Callback parameters

subject, key, type, value.

None for key means removal of all properties. None for value means removal of property with key key.

Examples
let metadata_listener = metadata.add_listener_local()
    .property(|subject, key, type_, value| {
        println!("Metadata property update: subject {subject}, key {key:?}, type {type_:?}, value {value:?}");
        0
    })
    .register();
pub fn register(self) -> MetadataListener

Subscribe to events and register any provided callbacks.